@@ -1,7 +1,7 @@
 context("canvasXpress Charts - Network")
 
-n <- read.table(system.file("extdata", "cX-lesmiserable-nodes.txt", package = "canvasXpress"), header = TRUE, sep = "\t", quote = "", fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
-e <- read.table(system.file("extdata", "cX-lesmiserable-edges.txt", package = "canvasXpress"), header = TRUE, sep = "\t", quote = "", fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
+n <- read.table(system.file("extdata", "cX-lesmiserable-nodes.txt.gz", package = "canvasXpress"), header = TRUE, sep = "\t", quote = "", fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
+e <- read.table(system.file("extdata", "cX-lesmiserable-edges.txt.gz", package = "canvasXpress"), header = TRUE, sep = "\t", quote = "", fill = TRUE, check.names = FALSE, stringsAsFactors = FALSE)
 
 test_that("network as data list items", {
     result <- canvasXpress(data        = list(nodeData = n, edgeData = e),
