@@ -16,7 +16,7 @@ test_that("cXbar3", {
 test_that("cXbar4", {
     check_ui_test(cXbar4())
 
-    warning("Inconsistent Tooltip: for Setosa/Sepal.Length dots, it's showing the second number in scientific format")
+    warning("Inconsistent Tooltip: for Setosa/Sepal.Length dots, sometimes the second number is in scientific format")
 })
 
 test_that("cXbar5", {
@@ -25,6 +25,8 @@ test_that("cXbar5", {
 
 test_that("cXbar6", {
     check_ui_test(cXbar6())
+
+    warning("smpTitle not readable because of the legend at the bottom")
 })
 
 test_that("cXbar7", {
@@ -42,11 +44,11 @@ test_that("cXbar9", {
 test_that("cXbar10", {
     check_ui_test(cXbar10())
 
-    warning("Durable overlay looks different in R than on the CX website, missing the following parm: smpOverlayProperties=list('Durable' = list('type'='Boolean'))")
+    warning("Durable overlay looks different in R than on the CX website, test is missing the following parm: smpOverlayProperties=list('Durable' = list('type'='Boolean'))")
 })
 
 test_that("cXbar11", {
     check_ui_test(cXbar11())
 
-    warning("Durable overlay looks different in R than on the CX website, missing the following parm: smpOverlayProperties=list('Durable' = list('type'='Boolean'))")
+    warning("Durable overlay looks different in R than on the CX website, test is missing the following parm: smpOverlayProperties=list('Durable' = list('type'='Boolean'))")
 })
