@@ -3,6 +3,8 @@ context("canvasXpress Web Charts - Circular")
 
 test_that("cXcircular1", {
     check_ui_test(cXcircular1())
+
+    warning("Hover effect results in a hyphen being displayed at the center if the plot is not resized.")
 })
 
 test_that("cXcircular2", {
@@ -11,14 +13,10 @@ test_that("cXcircular2", {
 
 test_that("cXcircular3", {
     check_ui_test(cXcircular3())
-
-    warning("sample tooltips incorrect, e.g. s108 gives s2")
 })
 
 test_that("cXcircular4", {
     check_ui_test(cXcircular4())
-
-    warning("sample tooltips incorrect, e.g. s108 gives s2")
 })
 
 test_that("cXcircular5", {
