@@ -3,24 +3,18 @@ context("canvasXpress Web Charts - Network")
 
 test_that("cXnetwork1", {
     check_ui_test(cXnetwork1())
-
-    warning('layout depends on space/etc, may be off from web example')
 })
 
 test_that("cXnetwork2", {
     check_ui_test(cXnetwork2())
 })
 
-
 test_that("cXnetwork3", {
     check_ui_test(cXnetwork3())
 })
 
-
 test_that("cXnetwork4", {
     check_ui_test(cXnetwork4())
-
-    warning('layout depends on space/etc, may be off from web example')
 })
 
 test_that("cXnetwork5", {
@@ -29,20 +23,14 @@ test_that("cXnetwork5", {
 
 test_that("cXnetwork6", {
     check_ui_test(cXnetwork6())
-
-    warning('legend position and appearance may depend on browser')
 })
 
 test_that("cXnetwork7", {
     check_ui_test(cXnetwork7())
-
-    warning('legend position and appearance may depend on browser')
 })
 
 test_that("cXnetwork8", {
     check_ui_test(cXnetwork8())
-
-    warning('legend position and appearance may depend on browser')
 })
 
 test_that("cXnetwork9", {
@@ -56,3 +44,11 @@ test_that("cXnetwork10", {
 test_that("cXnetwork11", {
     check_ui_test(cXnetwork11())
 })
+
+test_that("cXnetwork12", {
+    check_ui_test(cXnetwork12())
+})
+
+test_that("cXnetwork13", {
+    check_ui_test(cXnetwork13())
+})
