@@ -7,8 +7,6 @@ test_that("cXradar1", {
 
 test_that("cXradar2", {
     check_ui_test(cXradar2())
-
-    warning('radar has brown overlay on mouseover (if plot is not resized) - RStudio Viewer')
 })
 
 test_that("cXradar3", {
@@ -17,6 +15,8 @@ test_that("cXradar3", {
 
 test_that("cXradar4", {
     check_ui_test(cXradar4())
+
+    warning('Hover over any point - highlights middle circle point')
 })
 
 test_that("cXradar5", {
